package com.faraphel.tasks_valider.connectivity.task.api

import com.faraphel.tasks_valider.connectivity.task.session.TaskSession
import com.faraphel.tasks_valider.database.api.client.TaskEntityHttpClient
import com.faraphel.tasks_valider.database.entities.SessionEntity
import com.faraphel.tasks_valider.database.entities.error.HttpException
import com.faraphel.tasks_valider.utils.parser


/**
 * Interface to communicate with the server session manager
 */
class TaskSessionManagerClientApi(private val client: TaskEntityHttpClient) {
    /**
     * Create a new session
     * @param cardId the id of the user's card
     * @param password the password of the user
     */
    fun newFromCardId(cardId: String, password: String): TaskSession {
        val response = this.client.post(
            "sessions/self",
            parser.toJson(mapOf(
                "card_id" to cardId,
                "password" to password
            ))
        )

        // in case of error, notify it
        if (!response.isSuccessful)
            throw HttpException(response.code)

        val data = response.body.string()

        // parse the result
        return parser.fromJson(
            data,
            TaskSession::class.java
        )

    }

    /**
     * Get the current session
     */
    fun getSelf(): TaskSession {
        val response = this.client.get("sessions/self")

        // in case of error, notify it
        if (!response.isSuccessful)
            throw HttpException(response.code)

        // parse the result
        return parser.fromJson(
            response.body.string(),
            TaskSession::class.java
        )
    }
}
