package com.faraphel.tasks_valider.database.dao

import androidx.room.Dao
import androidx.room.Query
import com.faraphel.tasks_valider.database.dao.base.BaseCronDao
import com.faraphel.tasks_valider.database.dao.base.BaseSessionDao
import com.faraphel.tasks_valider.database.dao.base.BaseTaskDao
import com.faraphel.tasks_valider.database.entities.ClassEntity
import com.faraphel.tasks_valider.database.entities.RelationPersonSessionSubjectEntity
import com.faraphel.tasks_valider.database.entities.SubjectEntity
import com.faraphel.tasks_valider.database.entities.TaskEntity

@Dao
interface SubjectDao : BaseTaskDao<SubjectEntity> {
    @Query("SELECT * FROM ${SubjectEntity.TABLE_NAME}")
    override fun getAll(): List<SubjectEntity>

    @Query(
        "SELECT * FROM ${SubjectEntity.TABLE_NAME} " +
        "WHERE id IN (" +
            "SELECT subject_id FROM ${RelationPersonSessionSubjectEntity.TABLE_NAME} " +
            "WHERE session_id = :sessionId" +
        ")"
    )
    override fun getAllBySession(sessionId: Long): List<SubjectEntity>

    /**
     * Get the object from its identifier
     */
    @Query("SELECT * FROM ${SubjectEntity.TABLE_NAME} WHERE id = :id")
    fun getById(id: Long): SubjectEntity?

    /**
     * Get all the tasks available in a subject
     * @param id the id of the subject
     */
    @Query("SELECT * FROM ${TaskEntity.TABLE_NAME} WHERE subject_id = :id")
    fun getTasks(id: Long): List<TaskEntity>
}
