package com.faraphel.tasks_valider.ui.screen.communication.internet

import android.app.Activity
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.MutableState
import androidx.compose.runtime.mutableIntStateOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.faraphel.tasks_valider.connectivity.task.TaskClient
import com.faraphel.tasks_valider.connectivity.task.session.TaskSession
import com.faraphel.tasks_valider.ui.screen.authentication.AuthenticationClientScreen
import com.faraphel.tasks_valider.ui.screen.communication.DEFAULT_SERVER_ADDRESS
import com.faraphel.tasks_valider.ui.screen.communication.DEFAULT_SERVER_PORT
import com.faraphel.tasks_valider.ui.screen.communication.RANGE_SERVER_PORT
import com.faraphel.tasks_valider.ui.screen.task.TaskSessionController


@Composable
fun CommunicationInternetClientScreen(activity: Activity) {
    val client = remember { mutableStateOf<TaskClient?>(null) }
    val session = remember { mutableStateOf<TaskSession?>(null) }

    // if the client is not connected, show the connection screen
    if (client.value == null)
        return CommunicationInternetClientContent(client)
    // if the user is not authenticated, show the authentication screen
    if (session.value == null)
        return AuthenticationClientScreen(activity, client.value!!, session)

    // show the main screen
    TaskSessionController(
        activity,
        client.value!!,
        session.value!!.person,
    )
}


@Composable
fun CommunicationInternetClientContent(client: MutableState<TaskClient?>) {
    val serverAddress = remember { mutableStateOf(DEFAULT_SERVER_ADDRESS) }
    val serverPort = remember { mutableIntStateOf(DEFAULT_SERVER_PORT) }

    Column(
        modifier = Modifier.fillMaxSize(),
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        // title
        Text(
            text = "Connection",
            fontSize = 32.sp
        )

        // separator
        Spacer(modifier = Modifier.height(24.dp))

        // server address
        TextField(
            value = serverAddress.value,
            placeholder = { Text("server IP") },
            onValueChange = { text -> serverAddress.value = text }
        )

        // server port
        TextField(
            value = serverPort.intValue.toString(),
            placeholder = { Text("server port") },
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Number),
            onValueChange = { text ->
                val port = text.toInt()
                if (port in RANGE_SERVER_PORT) {
                    serverPort.intValue = port
                }
            }
        )

        // separator
        Spacer(modifier = Modifier.height(24.dp))

        // connect button
        Button(onClick = {
            // TODO(Faraphel): check if the server is reachable
            client.value = TaskClient(serverAddress.value, serverPort.intValue)
        }) {
            Text("Connect")
        }
    }
}