package com.faraphel.tasks_valider.ui.screen.scan.qr

import android.Manifest
import android.app.Activity
import android.content.pm.PackageManager
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.runtime.*
import androidx.compose.ui.Modifier
import androidx.compose.ui.viewinterop.AndroidView
import com.google.zxing.BarcodeFormat
import com.journeyapps.barcodescanner.BarcodeResult
import com.journeyapps.barcodescanner.DecoratedBarcodeView
import com.journeyapps.barcodescanner.DefaultDecoderFactory

/**
 * Screen to scan a Barcode / QR Code
 */
@Composable
fun ScanBarcodeScreen(activity: Activity, barcode: MutableState<BarcodeResult?>) {
    Box(modifier = Modifier.fillMaxSize()) {
        // check and prompt for the camera permission
        if (activity.checkSelfPermission(Manifest.permission.CAMERA) != PackageManager.PERMISSION_GRANTED)
            // FIXME(Faraphel): seem to crash the application
            activity.requestPermissions(arrayOf(Manifest.permission.CAMERA), 1)

        // AndroidView is used because "DecoratedBarcodeView" only support the legacy view system
        AndroidView(factory = {
            DecoratedBarcodeView(activity).apply {
                this.decoderFactory = DefaultDecoderFactory(listOf(BarcodeFormat.QR_CODE))
                this.initializeFromIntent(activity.intent)
                this.decodeContinuous { result -> barcode.value = result }
                this.resume()
            }
        })
    }
}
