package com.faraphel.tasks_valider.ui.widgets.connectivity

import android.net.wifi.p2p.WifiP2pDevice
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.MutableState
import androidx.compose.ui.graphics.Color


/**
 * A widget that represent a WiFi-Direct device.
 * @param device the device that should be represented
 * @param deviceState a state that will be updated to the device when it is selected
 */
@Composable
fun WifiP2pDeviceWidget(device: WifiP2pDevice, deviceState: MutableState<WifiP2pDevice?>? = null) {
    Button(onClick = { if (deviceState != null) deviceState.value = device }) {
        Column {
            Row {
                Text(text = "Name: ")
                Text(text = device.deviceName)
            }
            Row {
                Text(text = "Is Owner: ")
                Text(text = device.isGroupOwner.toString())
            }
            Row {
                Text(text = "Address: ", color = Color.LightGray)
                Text(text = device.deviceAddress, color = Color.LightGray)
            }
            Row {
                Text(text = "Primary Type: ", color = Color.Green)
                Text(text = device.primaryDeviceType, color = Color.Green)
            }
            Row {
                Text(text = "Status: ", color = Color.Yellow)
                Text(text = device.status.toString(), color = Color.Yellow)
            }
        }
    }
}